.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.support.support module
-------------------------------

.. automodule:: oc_ocdm.support.support
   :members:
   :undoc-members:
   :show-inheritance:
